public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] gentoo-x86 commit in net-misc/openswan/files: openswan-2.4.14-getline.patch openswan-2.6.19-qa-fixes.patch openswan-2.6.19-gentoo.patch openswan-2.4.13-gentoo-fixed.patch openswan-2.4.13-deprecated-ldap.patch
@ 2009-06-14 10:25 Alin Nastac (mrness)
  0 siblings, 0 replies; only message in thread
From: Alin Nastac (mrness) @ 2009-06-14 10:25 UTC (permalink / raw
  To: gentoo-commits

mrness      09/06/14 10:25:31

  Added:                openswan-2.4.14-getline.patch
  Removed:              openswan-2.6.19-qa-fixes.patch
                        openswan-2.6.19-gentoo.patch
                        openswan-2.4.13-gentoo-fixed.patch
                        openswan-2.4.13-deprecated-ldap.patch
  Log:
  Fix compile error when built against glibc-2.10 (#271987).
  Remove obsolete versions.
  (Portage version: 2.1.6.13/cvs/Linux x86_64)

Revision  Changes    Path
1.1                  net-misc/openswan/files/openswan-2.4.14-getline.patch

file : http://sources.gentoo.org/viewcvs.py/gentoo-x86/net-misc/openswan/files/openswan-2.4.14-getline.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewcvs.py/gentoo-x86/net-misc/openswan/files/openswan-2.4.14-getline.patch?rev=1.1&content-type=text/plain

Index: openswan-2.4.14-getline.patch
===================================================================
diff -Nru openswan-2.4.14.orig/lib/libopenswan/optionsfrom.c openswan-2.4.14/lib/libopenswan/optionsfrom.c
--- openswan-2.4.14.orig/lib/libopenswan/optionsfrom.c	2004-04-09 21:00:38.000000000 +0300
+++ openswan-2.4.14/lib/libopenswan/optionsfrom.c	2009-06-01 22:21:56.000000000 +0300
@@ -31,7 +31,7 @@
 
 static const char *dowork(const char *, int *, char ***, int);
 static const char *getanarg(FILE *, struct work *, char **);
-static char *getline(FILE *, char *, size_t);
+static char *of_getline(FILE *, char *, size_t);
 
 /*
  - optionsfrom - add some options, taken from a file, to argc/argv
@@ -149,7 +149,7 @@
 	char *endp;
 
 	while (w->pending == NULL) {	/* no pending line */
-		if ((w->line = getline(f, w->buf, sizeof(w->buf))) == NULL)
+		if ((w->line = of_getline(f, w->buf, sizeof(w->buf))) == NULL)
 			return "error in line read";	/* caller checks EOF */
 		if (w->line[0] != '#' &&
 				*(w->line + strspn(w->line, " \t")) != '\0')
@@ -171,7 +171,7 @@
 			if (*linep == NULL)
 				return "out of memory for new line";
 			strcpy(*linep, p);
-		} else			/* getline already malloced it */
+		} else			/* of_getline already malloced it */
 			*linep = p;
 		return NULL;
 	}
@@ -203,10 +203,10 @@
 }
 
 /*
- - getline - read a line from the file, trim newline off
+ - of_getline - read a line from the file, trim newline off
  */
 static char *			/* pointer to line, NULL for eof/error */
-getline(f, buf, bufsize)
+of_getline(f, buf, bufsize)
 FILE *f;
 char *buf;			/* buffer to use, if convenient */
 size_t bufsize;			/* size of buf */






^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2009-06-14 10:25 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2009-06-14 10:25 [gentoo-commits] gentoo-x86 commit in net-misc/openswan/files: openswan-2.4.14-getline.patch openswan-2.6.19-qa-fixes.patch openswan-2.6.19-gentoo.patch openswan-2.4.13-gentoo-fixed.patch openswan-2.4.13-deprecated-ldap.patch Alin Nastac (mrness)

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox